<?php
namespace Feedier\Admin;

/**
 * Class Settings
 *
 * @package Feedier\Admin
 */
class Settings
{

	/**
	 * Return the tab title
	 *
	 * @return string
	 */
	public function getTitle()
	{
		return __('Feedier connection', 'feedier');
	}

	/**
	 * Whether the page is ready or not
	 *
	 * @param $not_ready
	 *
	 * @return boolean
	 */
	public function isActive($not_ready)
	{
		return !$not_ready;
	}

	/**
	 * Write the tab markup
	 *
	 * @param boolean   $not_ready - whether the Api settings are correct and set or not
	 * @param array     $data - the current options data
	 *
	 * @return void
	 */
	public function writeMarkup($not_ready, $data)
	{

		?>

        <div class="row">
            <div class="col">

                <div class="mt-3">
	                <?php if ($not_ready): ?>
                        <p>
                            <b><?php _e('Get ready in 3 steps', 'feedier'); ?></b>
                            <br>
                            <br>
			                <?php _e('1. <a href="https://feedier.com" target="_blank">Create a Feedier account here</a>', 'feedier'); ?>
                            <br>
			                <?php _e('2. <a href="https://dashboard.feedier.com/#/integrations" target="_blank">Get your API keys from the API & webhooks page here</a>', 'feedier'); ?>
                            <br>
			                <?php _e('3. Copy and paste the private and public API keys in the box below and <b>reload the page</b>.', 'feedier'); ?>
                        </p>
	                <?php else: ?>
		                <?php _e('Great! You can <b>create a display rule</b> to show the widget and access your <a href="https://dashboard.feedier.com" target="_blank">Feedier dashboard here</a>.', 'feedier'); ?>
	                <?php endif; ?>
                </div>

                <table class="form-table mt-3">
                    <tbody>
                    <tr>
                        <td scope="row">
                            <label><?php _e( 'Public key', 'feedier' ); ?></label>
                        </td>
                        <td>
                            <input name="feedier_public_key"
                                   id="feedier_public_key"
                                   class="regular-text"
                                   type="text"
                                   value="<?php echo (isset($data['public_key'])) ? $data['public_key'] : ''; ?>"/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label><?php _e( 'Private key', 'feedier' ); ?></label>
                        </td>
                        <td>
                            <input name="feedier_private_key"
                                   id="feedier_private_key"
                                   class="regular-text"
                                   type="text"
                                   value="<?php echo (isset($data['private_key'])) ? $data['private_key'] : ''; ?>"/>
                        </td>
                    </tr>
                    </tbody>
                </table>

            </div>
            <div class="col text-right">

                <img src="<?php echo FEEDIER_URL .'assets/images/connection.jpg' ?>" width="400">

            </div>
        </div>

		<?php
	}

}