<?php
namespace Feedier\Admin;

/**
 * Class WidgetDesign
 *
 * @package Feedier\Admin
 */
class WidgetDesign
{

	/**
	 * Return the tab title
	 *
	 * @return string
	 */
	public function getTitle()
	{
		return __('Widget design', 'feedier');
	}

	/**
	 * Whether the page is ready or not
	 *
	 * @param boolean $not_ready
	 * @param array   $data
	 *
	 * @return boolean
	 */
	public function isActive($not_ready)
	{
		return !$not_ready;
	}

	/**
	 * Write the tab markup
	 *
	 * @param boolean   $has_wc - whether WC is enabled or not
	 * @param array     $data - the current options data
	 * @param array     $api_response
	 *
	 * @return void
	 */
	public function writeMarkup($has_wc, $data, $api_response)
	{

		?>

        <div class="row">

            <div class="col">
                <h3><?php _e( 'Main options', 'feedier' ); ?></h3>

                <table class="form-table">
                    <tbody>
                    <tr>
                        <td scope="row">
                            <label>
					            <?php _e( 'Widget title', 'feedier' ); ?>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_title"
                                   id="feedier_widget_title"
                                   type="text"
                                   class="regular-text"
                                   value="<?php echo (isset($data['widget_title'])) ? esc_attr__($data['widget_title']) : 'Give your Feedback'; ?>"/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label><?php _e( 'Widget position', 'feedier' ); ?></label>
                        </td>
                        <td>
                            <select name="feedier_widget_position"
                                    id="feedier_widget_position">
                                <option value="left" <?php echo (!isset($data['widget_position']) || (isset($data['widget_position']) && $data['widget_position'] === 'left')) ? 'selected' : ''; ?>>
						            <?php _e( 'Left side', 'feedier' ); ?>
                                </option>
                                <option value="right" <?php echo (isset($data['widget_position']) && $data['widget_position'] === 'right') ? 'selected' : ''; ?>>
						            <?php _e( 'Right side', 'feedier' ); ?>
                                </option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label><?php _e( 'Widget layout', 'feedier' ); ?></label>
                        </td>
                        <td>
                            <select name="feedier_widget_direction"
                                    id="feedier_widget_direction">
                                <option value="vertical" <?php echo (!isset($data['widget_layout']) || (isset($data['widget_layout']) && $data['widget_layout'] === 'vertical')) ? 'selected' : ''; ?>>
						            <?php _e( 'Vertical', 'feedier' ); ?>
                                </option>
                                <option value="horizontal" <?php echo (isset($data['widget_layout']) && $data['widget_layout'] === 'horizontal') ? 'selected' : ''; ?>>
						            <?php _e( 'Horizontal', 'feedier' ); ?>
                                </option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label>
			                    <?php _e( 'Expire days', 'feedier' ); ?>
                                <br>
                                <small><?php _e( '(number of days before showing widget again after clicked)', 'feedier' ); ?></small>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_extra_line"
                                   id="feedier_widget_extra_line"
                                   type="text"
                                   class="regular-text"
                                   value="<?php echo (isset($data['widget_expire'])) ? esc_attr__($data['widget_expire']) : '15'; ?>"/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label>
					            <?php _e( 'Extra content', 'feedier' ); ?>
                                <br>
                                <small><?php _e( '(added in the widget to give more details)', 'feedier' ); ?></small>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_extra_line"
                                   id="feedier_widget_extra_line"
                                   type="text"
                                   class="regular-text"
                                   value="<?php echo (isset($data['widget_extra_line'])) ? esc_attr__($data['widget_extra_line']) : ''; ?>"/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label>
					            <?php _e( 'Display form in site', 'feedier' ); ?>
                                <br>
                                <small><?php _e( '(otherwise open in new tab)', 'feedier' ); ?></small>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_in_site"
                                   id="feedier_widget_in_site"
                                   type="checkbox"
					            <?php echo (isset($data['widget_in_site']) && $data['widget_in_site']) ? 'checked' : ''; ?>/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label>
			                    <?php _e( 'Skip intro content', 'feedier' ); ?>
                                <br>
                                <small><?php _e( '(otherwise show intro text before form)', 'feedier' ); ?></small>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_skip_intro"
                                   id="feedier_widget_skip_intro"
                                   type="checkbox"
			                    <?php echo (isset($data['widget_intro']) && $data['widget_intro']) ? 'checked' : ''; ?>/>
                        </td>
                    </tr>
                    <tr>
                        <td scope="row">
                            <label>
					            <?php _e( 'Shaking effect', 'feedier' ); ?>
                                <br>
                                <small><?php _e( '(after 10s without any click)', 'feedier' ); ?></small>
                            </label>
                        </td>
                        <td>
                            <input name="feedier_widget_shake"
                                   id="feedier_widget_shake"
                                   type="checkbox"
					            <?php echo (isset($data['widget_shake']) && $data['widget_shake']) ? 'checked' : ''; ?>/>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </div>
            <div class="col pl-4">
                <h3><?php _e( 'Advanced', 'feedier' ); ?></h3>

                <div class="text-left">
                    <?php if (isset($api_response['data'])) : ?>
                        <a href="<?php echo get_site_url() ?>?feedier_widget_preview=<?php echo $api_response['data'][0]['id']; ?>" target="_blank" class="button-secondary">
                            <?php _e( 'Preview widget', 'feedier' ); ?>

                            <span class="dashicons dashicons-external"></span>
                        </a>
                    <?php endif; ?>

                    <a href="https://manual.feedier.com/docs/feedier-documentation/collect-feedback/dynamic-widget/"
                       target="_blank"
                       class="button-secondary">
		                <?php _e( 'Widget documentation', 'feedier' ); ?>

                        <span class="dashicons dashicons-external"></span>
                    </a>
                </div>

                <div>
                    <p><b><?php _e( 'Custom CSS', 'feedier' ); ?></b></p>
                    <p><?php _e( 'You can apply your own design to the widget using the following CSS classes:', 'feedier' ); ?></p>
                    <ol>
                        <li><code>.feedier-widget--engager</code> - <?php _e( 'The widget wrapper', 'feedier' ); ?></li>
                        <li><code>.feedier-widget__caller</code> - <?php _e( 'The widget clickable box', 'feedier' ); ?></li>
                        <li><code>.feedier-widget__popup__wrapper</code> - <?php _e( 'The widget intro content', 'feedier' ); ?></li>
                    </ol>

                    <img src="<?php echo FEEDIER_URL .'assets/images/widget.jpg' ?>" width="400">
                </div>

                <div class="mt-3">
                    <p><b><?php _e( 'Javascript API', 'feedier' ); ?></b></p>
                    <p><?php _e( 'You can control the widget with Javascript when it is loaded on the page', 'feedier' ); ?></p>
                    <ul>
                        <li><code>feedierWidget.engager.show()</code> - <?php _e( 'Will show the web widget. No matter if it’s been hidden before. Can be checked with the isAvailable() method.', 'feedier' ); ?></li>
                        <li><code>feedierWidget.engager.hide()</code> - <?php _e( 'Will hide the web widget for the current user.', 'feedier' ); ?></li>
                        <li><code>feedierWidget.engager.toggle()</code> - <?php _e( 'Will open or close the web widget’s content depending on the current status.', 'feedier' ); ?></li>
                        <li><code>feedierWidget.engager.shake()</code> - <?php _e( 'Will shake the web button for 1 second to attract the visitor’s attention.', 'feedier' ); ?></li>
                    </ul>
                </div>

            </div>

        </div>

		<?php

	}

}