<?php
namespace Feedier\Admin;

/**
 * Class WidgetRules
 *
 * @package Feedier\Admin
 */
class WidgetRules
{

	/**
	 * Return the tab title
	 *
	 * @return string
	 */
	public function getTitle()
	{
		return __('Widget display rules', 'feedier');
	}

	/**
	 * Whether the page is ready or not
	 *
	 * @param boolean $not_ready
	 * @param array   $data
	 *
	 * @return boolean
	 */
	public function isActive($not_ready, $data)
	{
		return (isset($data['rules']) && sizeof($data['rules']) > 0);
	}

	/**
	 * Write the tab markup
	 *
	 * @param boolean   $has_wc - whether WC is enabled or not
	 * @param array     $data - the current options data
	 * @param array     $api_response
	 *
	 * @return void
	 */
	public function writeMarkup($has_wc, $data, $api_response)
	{
		$data['widgets'] = (isset($data['widgets'])) ? $data['widgets'] : [];
		$api_response['data'] = (isset($api_response['data'])) ? $api_response['data'] : [];

		$rules = [
		    [
                'id' => 'load',
                'name' => __('On page load', 'feedier'),
            ],
			[
				'id' => 'bottom',
				'name' => __('Reach page bottom', 'feedier'),
			],
			[
				'id' => 'exit',
				'name' => __('Page exit', 'feedier'),
			],
			[
				'id' => 'trigger',
				'name' => __('Trigger manually', 'feedier'),
			]
        ];

		?>

        <div id="data-layer">
            <div data-widgets='<?php echo (!empty($data['widgets'])) ? json_encode($data['widgets']) : ''; ?>'></div>

	        <?php foreach ($api_response['data'] as $form) : ?>
                <div data-type="forms"
                     data-id="<?php echo $form['id']; ?>"
                     data-name="<?php echo $form['name']; ?>"></div>
	        <?php endforeach; ?>

            <div data-type="pages"
                 data-id="all"
                 data-name="<?php _e('All pages', 'feedier'); ?>"></div>

	        <?php foreach(get_pages() as $page) : ?>
                <div data-type="pages"
                     data-id="<?php echo $page->ID; ?>"
                     data-name="<?php echo $page->post_title; ?>"></div>
	        <?php endforeach; ?>

	        <?php foreach(get_categories() as $category) : ?>
                <div data-type="categories"
                     data-id="<?php echo $category->term_id; ?>"
                     data-name="<?php echo $category->name; ?>"></div>
	        <?php endforeach; ?>

	        <?php foreach($rules as $rule) : ?>
                <div data-type="rules"
                     data-id="<?php echo $rule['id']; ?>"
                     data-name="<?php echo $rule['name']; ?>"></div>
	        <?php endforeach; ?>
        </div>

        <table id="addable" class="form-table">
            <thead>
                <tr>
                    <td><?php _e( 'Form', 'feedier' ); ?></td>
                    <td><?php _e( 'Page or category', 'feedier' ); ?></td>
                    <td><?php _e( 'Rule', 'feedier' ); ?></td>
                    <td><?php _e( 'Delay (in ms)', 'feedier' ); ?></td>
                    <td></td>
                </tr>
            </thead>
            <tbody>
            <input type="hidden" name="feedier_widgets">
            </tbody>
            <tfoot>
                <tr>
                    <td colspan="5" style="text-align: center;">
                        <input type="button"
                               class="button-secondary mt-3"
                               id="add-row"
                               value="<?php _e('Add widget display rule', 'feedier'); ?>" />
                    </td>
                </tr>
            </tfoot>
        </table>

        <p class="mt-3">
            <?php _e('<b>ℹ️ Rule explanations</b><br> <b>On page load</b>: the widget is displayed after the page is loaded - <b>Reach page bottom</b>: the widget is displayed when the user reaches the page bottom - <b>Page exit</b>: the widget is displayed when an intent to exit the page is detected - <b>Trigger manually</b> (advanced): the widget is only displayed when you use the Javascript API .show() method.') ?>
        </p>

		<?php
	}

}