<?php
namespace Feedier;

/**
 * Class Engager
 *
 * @package Feedier
 */
class Engager extends Main
{
	/**
	 * Engager constructor.
	 *
	 * The main plugin actions registered for WordPress
	 */
	public function __construct()
	{
		add_action('wp_footer', array($this, 'addFooterCode'));
	}

	/**
	 * Output widget code
     *
     * @param array $widget
     * @param array $data
	 */
	private function outputWidget($widget, $data)
    {
	    ?>

        <div class="feedier-widget feedier-widget--hide"
             data-type="engager"
             data-position="<?php echo (isset($data['widget_position'])) ? esc_attr($data['widget_position']) : 'right'; ?>"
             data-layout="<?php echo (isset($data['widget_layout'])) ? esc_attr($data['widget_layout']) : 'horizontal'; ?>"
             data-display-probability="<?php echo (isset($data['widget_display_probability'])) ? esc_attr($data['widget_display_probability']) : '100'; ?>"
             data-shake="<?php echo (isset($data['widget_shake'])) ? esc_attr($data['widget_shake']) : false; ?>"
             data-expire="<?php echo (isset($data['widget_expire'])) ? esc_attr($data['widget_expire']) : 15; ?>"
             data-in-site="<?php echo (isset($data['widget_in_site'])) ? esc_attr($data['widget_in_site']) : true; ?>"
             data-skip-intro="<?php echo (isset($data['widget_skip_intro'])) ? esc_attr($data['widget_skip_intro']) : true; ?>"
             data-carrier-id="<?php echo (isset($widget['form_id'])) ? esc_attr($widget['form_id']) : '0'; ?>"
             data-custom-fields="page=<?php echo get_the_title(); ?>"
             data-key="<?php echo (isset($data['public_key'])) ? $data['public_key'] : '0'; ?>"
		    <?php if (isset($data['widget_title']) && !empty($data['widget_title'])): ?>
                data-widget-title="<?php esc_attr_e($data['widget_title']); ?>"
		    <?php endif; ?>
		    <?php if (isset($data['widget_extra_line']) && !empty($data['widget_extra_line'])): ?>
                data-extra-line="<?php esc_attr_e($data['widget_extra_line']); ?>"
		    <?php endif; ?>
		    <?php if (isset($data['widget_offset_x']) && !empty($data['widget_offset_x'])): ?>
                data-offset-x="<?php esc_attr_e($data['widget_offset_x']); ?>"
		    <?php endif; ?>
		    <?php if (isset($data['widget_offset_y']) && !empty($data['widget_offset_y'])): ?>
                data-offset-y="<?php esc_attr_e($data['widget_offset_y']); ?>"
		    <?php endif; ?>
		    <?php if (isset($widget['force']) && $widget['force']): ?>
                data-force="true"
            <?php else: ?>
		    <?php endif; ?>
        ></div>

	    <?php
    }

	/**
     * Checks whether a widget is displayed
     *
	 * @param array $widget
     *
     * @return boolean
	 */
    private function isWidgetDisplayed($widget)
    {
        $displayed = false;

        if (!isset($widget['page_id'])) {
            $displayed = true;
        } else if ($widget['page_id'] === 'page-all') {
            $displayed = true;
        } else if (substr($widget['page_id'], 0, 5) === 'page-') {
            $page_id = (int) explode('-', $widget['page_id'])[1];
	        $displayed = is_page($page_id);
        } else if (substr($widget['page_id'], 0, 9) === 'category-') {
	        $page_id = (int) explode('-', $widget['page_id'])[1];
	        $displayed = is_category($page_id);
        }

        return $displayed;
    }

	/**
     * Output display rules
     *
	 * @param array $widget
	 */
    private function outputDisplayScript($widget)
    {
        $delay = (!empty($widget['delay'])) ? (int) $widget['delay'] : 0;
	    $delay = 100 + $delay;

        ?>
        <script data-feedier-script="true" type="application/javascript">
			document.getElementsByClassName('feedier-widget')[0].addEventListener('feedierWidget.init', function () {
                feedierWidget.engager.hide();

                setTimeout(function () {
                    setTimeout(function () {
                        document.body.querySelector('.feedier-widget').classList.remove('feedier-widget--hide');

                        <?php if ($widget['rule_id'] === 'load') : ?>
                                feedierWidget.engager.show();
                            <?php elseif ($widget['rule_id'] === 'bottom') : ?>
                                window.onscroll = function () {
                                    if ((window.innerHeight + window.scrollY) >= document.body.offsetHeight) {
                                        feedierWidget.engager.show();
                                    }
                                };
                            <?php elseif ($widget['rule_id'] === 'exit') : ?>
                                document.addEventListener('mouseout', function (evt) {
                                    if (evt.toElement === null && evt.relatedTarget === null) {
                                        feedierWidget.engager.show();
                                    }
                                });
                            <?php endif; ?>
                        }, <?php echo $delay; ?>);
                }, 100);
            }, false);
        </script>
        <?php
    }

	/**
	 * Add the web app code to the page's footer
	 *
	 * This contains the widget markup used by the web app and the widget API call on the frontend
	 * We use the options saved from the admin page
	 *
	 * @return void
	 */
	public function addFooterCode()
	{
		$data = $this->getData();

		if (!empty($_GET['feedier_widget_preview'])) {
			$widget = [
                'form_id' => esc_attr__($_GET['feedier_widget_preview']),
                'rule_id' => 'load',
                'page_id' => 'page-all',
            ];

			$this->outputWidget($widget, $data);
			$this->outputDisplayScript($widget);

		    return;
        }

		// Only if the survey id is selected and saved
		if (empty($data) || !isset($data['widgets']) || empty($data['widgets']))
			return;

		// We only display the first rule
        foreach ($data['widgets'] as $widget) {
            $is_diplayed = $this->isWidgetDisplayed($widget);

            if (!$is_diplayed) {
                continue;
            }

            $this->outputWidget($widget, $data);
            $this->outputDisplayScript($widget);

            break;
        }
	}

}
